@@ -27,8 +27,8 @@ ff_glimpse <- function(.data, dependent=NULL, explanatory=NULL, digits = 1){
   if(is.null(dependent) && is.null(explanatory)){
     df.in = .data
   }else{
-    .data %>%
-      dplyr::select(dependent, explanatory) -> df.in
+    keep = names(.data) %in% c(dependent, explanatory)
+    df.in = .data[keep]
   }
 
   # Continuous
@@ -36,10 +36,11 @@ ff_glimpse <- function(.data, dependent=NULL, explanatory=NULL, digits = 1){
     dplyr::select_if(is.numeric) -> df.numeric
 
   if(dim(df.numeric)[2]!=0){
-  df.numeric %>%
-    broom::tidy(na.rm = TRUE, interp=FALSE,skew = FALSE, ranges = TRUE,
+   df.numeric %>%
+    ff_describe(na.rm = TRUE, interp=FALSE, skew = FALSE, ranges = TRUE,
                 check=TRUE,fast=F, omit=FALSE) %>%
-    format(digits = digits, scientific=FALSE) -> df.numeric.out1
+    format(digits = digits, scientific=FALSE) %>%
+      dplyr::select(-vars)-> df.numeric.out1
 
   df.numeric %>%
     lapply(function(x){
@@ -48,8 +49,7 @@ ff_glimpse <- function(.data, dependent=NULL, explanatory=NULL, digits = 1){
     }) %>%
     do.call(rbind, .) -> df.numeric.out2
 
-  df.numeric.out = cbind(df.numeric.out1, df.numeric.out2)
-  df.numeric.out = df.numeric.out[,c(1,9, 2:7)]
+  df.numeric.out = data.frame(df.numeric.out2, df.numeric.out1)
 
   }else{
     df.numeric.out = df.numeric
@@ -80,26 +80,21 @@ ff_glimpse <- function(.data, dependent=NULL, explanatory=NULL, digits = 1){
                                 format(digits = 2) %>%
                                 paste(collapse=", "),
                               "-")
-      list(label=label, levels=levels, level_n=levels_n, n=n,
+      list(label=label, n=n, level_n=levels_n, levels=levels,
            levels_count=levels_count, levels_percent = levels_percent)
     }
     ) %>%
     do.call(rbind, .) %>%
     data.frame() -> df.factors.out
 
-  # df.factors.out$column = rownames(df.factors.out)
-  # rownames(df.factors.out) <- c()
-  # df.factors.out = df.factors.out[,c(7, 1:6)]
-  df.factors.out = df.factors.out[,1:6]
-
   }else{
     df.factors.out = df.factors
   }
 
   cat("Numerics\n")
-  print(df.numeric.out, row.names=FALSE)
-  cat("Factors\n")
-  print(df.factors.out)
+  print(df.numeric.out, row.names = TRUE)
+  cat("\nFactors\n")
+  print(df.factors.out, row.names = TRUE)
 
   return(invisible(
     list(
@@ -109,4 +104,5 @@ ff_glimpse <- function(.data, dependent=NULL, explanatory=NULL, digits = 1){
 }
 
 #' @rdname ff_glimpse
+#' @export
 finalfit_glimpse <- ff_glimpse
